@@ -148,11 +148,12 @@ sub GetCurrentUser {
         @_
     );
 
-    unless ( $args{'CurrentUser'} ) {
+    unless ( $args{'CurrentUser'} && $args{'CurrentUser'}->Id ) {
         $RT::Logger->error(
             "Filter::TakeAction executed when "
             ."CurrentUser (actor) is not authorized. "
-            ."Most probably you want to add Auth::MailFrom plugin before."
+            ."Most probably you want to add Auth::MailFrom plugin before "
+            ."Filter::TakeAction in the \@MailPlugins config."
         );
         return ( $args{'CurrentUser'}, $args{'AuthLevel'} );
     }
@@ -163,13 +164,33 @@ sub GetCurrentUser {
         return ( $args{'CurrentUser'}, $args{'AuthLevel'} );
     }
 
+    # If only a particular group may perform commands by mail,
+    # bail out
+    my $new_config = RT->can('Config') && RT->Config->can('Get');
+    my $group_id = $new_config
+                 ? RT->Config->Get('CommandByMailGroup')
+                 : $RT::CommandByMailGroup;
+
+    if (defined $group_id) {
+        my $group = RT::Group->new($args{'CurrentUser'});
+        $group->Load($group_id);
+
+        if (!$group->HasMemberRecursively($args{'CurrentUser'}->PrincipalObj)) {
+            $RT::Logger->debug("CurrentUser not in CommandByMailGroup");
+            return ($args{'CurrentUser'}, $args{'AuthLevel'});
+        }
+    }
+
+    $RT::Logger->debug("Running CommandByMail as ".$args{'CurrentUser'}->UserObj->Name);
+
+    # find the content
     my @content;
     my @parts = $args{'Message'}->parts_DFS;
     foreach my $part (@parts) {
         my $body = $part->bodyhandle or next;
 
         #if it looks like it has pseudoheaders, that's our content
-        if ( $body->as_string =~ /^(?:\S+):/m ) {
+        if ( $body->as_string =~ /^(?:\S+)(?:{.*})?:/m ) {
             @content = $body->as_lines;
             last;
         }
@@ -179,15 +200,17 @@ sub GetCurrentUser {
     my $found_pseudoheaders = 0;
     foreach my $line (@content) {
         next if $line =~ /^\s*$/ && ! $found_pseudoheaders;
-        last if $line !~ /^(?:(\S+)\s*?:\s*?(.*)\s*?|)$/;
+        last if $line !~ /^(?:(\S+(?:{.*})?)\s*?:\s*?(.*)\s*?|)$/;
         $found_pseudoheaders = 1;
         push( @items, $1 => $2 );
+        $RT::Logger->debug("Found pseudoheader: $1 => $2");
     }
     my %cmds;
     while ( my $key = _CanonicalizeCommand( lc shift @items ) ) {
         my $val = shift @items;
         # strip leading and trailing spaces
         $val =~ s/^\s+|\s+$//g;
+        $RT::Logger->debug("Got command $key => $val");
 
         if ( exists $cmds{$key} ) {
             $cmds{$key} = [ $cmds{$key} ] unless ref $cmds{$key};
@@ -223,6 +246,7 @@ sub GetCurrentUser {
     # If we're updating.
     if ( $args{'Ticket'}->id ) {
         $ticket_as_user->Load( $args{'Ticket'}->id );
+        $RT::Logger->debug("Updating Ticket ".$ticket_as_user->Id." in Queue ".$queue->Name);
 
         # we set status later as correspond can reopen ticket
         foreach my $attribute (grep !/^(Status|TimeWorked)/, @REGULAR_ATTRIBUTES, @TIME_ATTRIBUTES) {
@@ -242,6 +266,12 @@ sub GetCurrentUser {
             );
         }
 
+        # we want the queue the ticket is currently in, not the queue
+        # that was passed to rt-mailgate, otherwise we can't find the
+        # proper set of Custom Fields.  But, we have to do this after 
+        # we potentially update the Queue from @REGULAR_ATTRIBUTES
+        $queue = $ticket_as_user->QueueObj();
+
         foreach my $attribute (@DATE_ATTRIBUTES) {
             next unless ( $cmds{ lc $attribute } );
 
